@@ -2,7 +2,7 @@ use v5.14;
 use warnings;
 
 # ABSTRACT: Foreign function interface to PROJ coordinate transformation software
-package Geo::LibProj::FFI 0.05;
+package Geo::LibProj::FFI 0.06;
 
 
 use Alien::proj 1.07;
@@ -214,37 +214,37 @@ $ffi->custom_type( 'PJ_PRIME_MERIDIANS' => {
 
 # Geodetic, mostly spatiotemporal coordinate types
 {
-	package Geo::LibProj::FFI::PJ_XYZT 0.05;
+	package Geo::LibProj::FFI::PJ_XYZT 0.06;
 	sub new { Geo::LibProj::FFI::PJ_COORD->_new($_[1], qw{ x y z t }) }
-	package Geo::LibProj::FFI::PJ_UVWT 0.05;
+	package Geo::LibProj::FFI::PJ_UVWT 0.06;
 	sub new { Geo::LibProj::FFI::PJ_COORD->_new($_[1], qw{ u v w t })->uvwt }
-	package Geo::LibProj::FFI::PJ_LPZT 0.05;
+	package Geo::LibProj::FFI::PJ_LPZT 0.06;
 	sub new { Geo::LibProj::FFI::PJ_COORD->_new($_[1], qw{ lam phi z t }) }
-	package Geo::LibProj::FFI::PJ_OPK 0.05;
+	package Geo::LibProj::FFI::PJ_OPK 0.06;
 	sub new { Geo::LibProj::FFI::PJ_COORD->_new($_[1], qw{ o p k 0 }) }
 	# Rotations: omega, phi, kappa
-	package Geo::LibProj::FFI::PJ_ENU 0.05;
+	package Geo::LibProj::FFI::PJ_ENU 0.06;
 	sub new { Geo::LibProj::FFI::PJ_COORD->_new($_[1], qw{ e n u 0 }) }
 	# East, North, Up
-	package Geo::LibProj::FFI::PJ_GEOD 0.05;
+	package Geo::LibProj::FFI::PJ_GEOD 0.06;
 	sub new { Geo::LibProj::FFI::PJ_COORD->_new($_[1], qw{ s a1 a2 0 }) }
 	# Geodesic length, fwd azi, rev azi
 }
 
 # Classic proj.4 pair/triplet types - moved into the PJ_ name space
 {
-	package Geo::LibProj::FFI::PJ_UV 0.05;
+	package Geo::LibProj::FFI::PJ_UV 0.06;
 	sub new { Geo::LibProj::FFI::PJ_COORD->_new($_[1], qw{ u v 0 0 })->uv }
-	package Geo::LibProj::FFI::PJ_XY 0.05;
+	package Geo::LibProj::FFI::PJ_XY 0.06;
 	sub new { Geo::LibProj::FFI::PJ_COORD->_new($_[1], qw{ x y 0 0 }) }
-	package Geo::LibProj::FFI::PJ_LP 0.05;
+	package Geo::LibProj::FFI::PJ_LP 0.06;
 	sub new { Geo::LibProj::FFI::PJ_COORD->_new($_[1], qw{ lam phi 0 0 }) }
 	
-	package Geo::LibProj::FFI::PJ_XYZ 0.05;
+	package Geo::LibProj::FFI::PJ_XYZ 0.06;
 	sub new { Geo::LibProj::FFI::PJ_COORD->_new($_[1], qw{ x y z 0 }) }
-	package Geo::LibProj::FFI::PJ_UVW 0.05;
+	package Geo::LibProj::FFI::PJ_UVW 0.06;
 	sub new { Geo::LibProj::FFI::PJ_COORD->_new($_[1], qw{ u v w 0 })->uvw }
-	package Geo::LibProj::FFI::PJ_LPZ 0.05;
+	package Geo::LibProj::FFI::PJ_LPZ 0.06;
 	sub new { Geo::LibProj::FFI::PJ_COORD->_new($_[1], qw{ lam phi z 0 }) }
 }
 
@@ -256,7 +256,7 @@ $ffi->custom_type( 'PJ_PRIME_MERIDIANS' => {
 	# FFI::Platypus. Workaround: Use a Record with some additional Perl
 	# glue. The performance may not be perfect, but seems satisfactory.
 	
-	package Geo::LibProj::FFI::PJ_COORD 0.05;
+	package Geo::LibProj::FFI::PJ_COORD 0.06;
 	use FFI::Platypus::Record;
 	record_layout_1(qw{ double[4] v });
 	# First and foremost, it really is "just 4 numbers in a vector"
@@ -314,14 +314,14 @@ $ffi->custom_type( 'PJ_PRIME_MERIDIANS' => {
 	# legacy support:
 	sub _new {
 		my ($class, $values, @params) = @_;
-		warnings::warnif_at_level 'deprecated', 1, sprintf 'Creating %s values with new() is deprecated; use proj_coords() instead', caller =~ s/^.*://r;
+		warnings::warnif_at_level( 'deprecated', 1, sprintf 'Creating %s values with new() is deprecated; use proj_coords() instead', caller =~ s/^.*://r );
 		$values //= {};
 		@params = map { $values->{$_} // 0 } @params;
 		return $class->new({ 'v' => \@params });
 	}
 	sub _set {
 		my ($self, $values, @params) = @_;
-		warnings::warnif_at_level 'deprecated', 2, 'Setting PJ_COORD union members is deprecated; use proj_coords() instead';
+		warnings::warnif_at_level( 'deprecated', 2, 'Setting PJ_COORD union members is deprecated; use proj_coords() instead' );
 		if (ref $values eq 'HASH') {
 			@params = map { $values->{$_} } @params;
 		}
@@ -330,6 +330,7 @@ $ffi->custom_type( 'PJ_PRIME_MERIDIANS' => {
 		}
 		$self->v(\@params);
 	}
+	*warnings::warnif_at_level = sub { warnings::warnif(shift, pop) } if $^V lt v5.27;
 	
 	# union members:
 	sub xyzt { $_[1] ? $_[0]->_set($_[1], qw{ x   y   z  t }) : shift }
@@ -380,7 +381,7 @@ $ffi->type('record(Geo::LibProj::FFI::PJ_COORD)' => 'PJ_COORD');
 
 
 {
-	package Geo::LibProj::FFI::PJ_INFO 0.05;
+	package Geo::LibProj::FFI::PJ_INFO 0.06;
 	use FFI::Platypus::Record;
 	record_layout_1(
 		int    => 'major',       # Major release number
@@ -399,7 +400,7 @@ $ffi->type('record(Geo::LibProj::FFI::PJ_COORD)' => 'PJ_COORD');
 $ffi->type('record(Geo::LibProj::FFI::PJ_INFO)' => 'PJ_INFO');
 
 {
-	package Geo::LibProj::FFI::PJ_PROJ_INFO 0.05;
+	package Geo::LibProj::FFI::PJ_PROJ_INFO 0.06;
 	use FFI::Platypus::Record;
 	record_layout_1(
 		string => 'id',           # Name of the projection in question
@@ -412,7 +413,7 @@ $ffi->type('record(Geo::LibProj::FFI::PJ_INFO)' => 'PJ_INFO');
 $ffi->type('record(Geo::LibProj::FFI::PJ_PROJ_INFO)' => 'PJ_PROJ_INFO');
 
 {
-	package Geo::LibProj::FFI::PJ_GRID_INFO 0.05;
+	package Geo::LibProj::FFI::PJ_GRID_INFO 0.06;
 	use FFI::Platypus::Record;
 	record_layout_1(
 		'string(32)'  => 'gridname_NUL',         # name of grid
@@ -432,7 +433,7 @@ $ffi->type('record(Geo::LibProj::FFI::PJ_PROJ_INFO)' => 'PJ_PROJ_INFO');
 $ffi->type('record(Geo::LibProj::FFI::PJ_GRID_INFO)' => 'PJ_GRID_INFO');
 
 {
-	package Geo::LibProj::FFI::PJ_INIT_INFO 0.05;
+	package Geo::LibProj::FFI::PJ_INIT_INFO 0.06;
 	use FFI::Platypus::Record;
 	record_layout_1(
 		'string(32)'  => 'name_NUL',        # name of init file
@@ -578,7 +579,7 @@ Geo::LibProj::FFI - Foreign function interface to PROJ coordinate transformation
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
